<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../application.cpp" line="96"/>
        <source>Take a screenshot (deprecated, please use screengrab instead)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="105"/>
        <source>DIR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="105"/>
        <source>Take a screenshot and save it to the directory without showing the GUI (deprecated, please use screengrab instead)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="111"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[ФАЙЛ1, ФАЙЛ2,...]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImageShackUpload</name>
    <message>
        <location filename="../upload/imageshackupload.cpp" line="50"/>
        <source>unknown error response</source>
        <translation>відповідь сервера містить помилку без опису</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgBBUpload</name>
    <message>
        <location filename="../upload/imgbbupload.cpp" line="44"/>
        <source>unknown error response</source>
        <translation>відповідь сервера містить помилку без опису</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../upload/imgurupload.cpp" line="47"/>
        <source>unknown error response</source>
        <translation>відповідь сервера містить помилку без опису</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="204"/>
        <source>About</source>
        <translation>Про програму</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="205"/>
        <source>LXImage-Qt - a simple and fast image viewer

Copyright (C) 2013
LXQt Project: https://lxqt.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>LXImage-Qt - простий і швидкий переглядач зображень

Copyright (C) 2013
Проєкт LXQt: https://lxqt.org/

Автори:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>Open File</source>
        <translation>Відкрити файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="361"/>
        <location filename="../mainwindow.cpp" line="396"/>
        <source>Image files (%1)</source>
        <translation>Файли зображень (%1)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="374"/>
        <source>Open directory</source>
        <translation>Відкрити каталог</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <source>Save File</source>
        <translation>Зберегти файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="683"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (Завантаження...) - Переглядач малюнків</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="689"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (Не вдалося завантажити) - Переглядач малюнків</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="695"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Переглядач малюнків</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="741"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Переглядач малюнків</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1167"/>
        <source>Thumbnails</source>
        <translation>Значки</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1217"/>
        <source>EXIF Data</source>
        <translation>Дані EXIF</translation>
    </message>
</context>
<context>
    <name>LxImage::MruMenu</name>
    <message>
        <location filename="../mrumenu.cpp" line="49"/>
        <source>&amp;Clear</source>
        <translation>&amp;Очистити</translation>
    </message>
</context>
<context>
    <name>LxImage::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="74"/>
        <source>Use a modifier key to clear a shortcut
in the editing mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="283"/>
        <source>&lt;b&gt;Warning: Ambiguous shortcut detected!&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="300"/>
        <source>&lt;b&gt;Ambiguous shortcut not accepted.&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LxImage::SaveImageJob</name>
    <message>
        <location filename="../saveimagejob.cpp" line="54"/>
        <source>Cannot save with this image format!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LxImage::StatusBar</name>
    <message>
        <location filename="../statusbar.cpp" line="63"/>
        <source>Size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusbar.cpp" line="73"/>
        <source>Path:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="52"/>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="53"/>
        <source>ImgBB</source>
        <translation>ImgBB</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="54"/>
        <source>ImageShack</source>
        <translation>ImageShack</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="137"/>
        <source>Start</source>
        <translation>Почати</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="140"/>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="143"/>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="150"/>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Переглядач зображень</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="188"/>
        <location filename="../mainwindow.ui" line="634"/>
        <source>Annotations Toolbar</source>
        <translation>Панель анотацій</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="208"/>
        <source>&amp;About</source>
        <translation>&amp;Про програму</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="220"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="241"/>
        <source>&amp;Save</source>
        <translation>&amp;Зберегти</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="244"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <source>Save &amp;As</source>
        <translation>Зберегти &amp;як</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="256"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <source>&amp;Close</source>
        <translation>&amp;Закрити</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="268"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <source>Zoom &amp;In</source>
        <translation>З&amp;більшити</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Зменшити</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="292"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>&amp;Копіювати до буфера</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="310"/>
        <location filename="../mainwindow.ui" line="313"/>
        <source>Next File</source>
        <translation>Наступний файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <location filename="../mainwindow.ui" line="328"/>
        <source>Previous File</source>
        <translation>Попередній Файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>Open &amp;With...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>&amp;Recently Opened Files</source>
        <translation>&amp;Нещодавні файли</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>&amp;Open…</source>
        <translation>&amp;Відкрити</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>&amp;Reload File</source>
        <translation>&amp;Перезавантажити файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="316"/>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <source>Original Size</source>
        <translation>Оригінальний розмір</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>&amp;Fit</source>
        <translation>&amp;Підігнати</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>&amp;Обернути за год. стрілкою</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="370"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="379"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>Обернути проти &amp;год. стрілки</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="382"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="387"/>
        <source>P&amp;references</source>
        <translation>На&amp;лаштування</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="392"/>
        <source>&amp;Print</source>
        <translation>&amp;Друк</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="395"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="404"/>
        <source>First File</source>
        <translation>Перший файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="407"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>Last File</source>
        <translation>Останній файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="419"/>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>&amp;New Window</source>
        <translation>&amp;Нове вікно</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="431"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Віддзеркалити &amp;горизонтально</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="439"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="448"/>
        <source>Capture Screenshot</source>
        <translation>Зробити знімок екрана</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>F&amp;ull Screen</source>
        <translation>П&amp;овний екран</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="459"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="464"/>
        <source>Flip &amp;Vertically</source>
        <translation>Віддзеркалити &amp;вертикально</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="467"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="476"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>&amp;Вставити з буфера обміну</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="488"/>
        <source>&amp;Slide Show</source>
        <translation>&amp;Показ слайдів</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>&amp;Delete</source>
        <translation>В&amp;илучити</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="500"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Show Thumbnails</source>
        <translation>Показати значки</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="511"/>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="516"/>
        <source>File Properties</source>
        <translation>Властивості файлу</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="525"/>
        <source>Open &amp;Directory</source>
        <translation>Відкрити &amp;Каталог</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="528"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="537"/>
        <source>Upload</source>
        <translation>Вивантажити</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="540"/>
        <source>Upload the image</source>
        <translation>Вивантажити це зображення</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="548"/>
        <source>Show EXIF Data</source>
        <translation>Показати дані EXIF</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="560"/>
        <source>No Tool</source>
        <translation>Не малювати</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>Deselect all drawing tools</source>
        <translation>Скасувати вибір інструменту малювання</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="575"/>
        <source>Draw Arrow</source>
        <translation>Стрілка</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="578"/>
        <source>Draw an arrow</source>
        <translation>Малювати стрілку</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="590"/>
        <source>Draw Rectangle</source>
        <translation>Прямокутник</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="593"/>
        <source>Draw a hollow rectangle</source>
        <translation>Малювати прямокутну раму</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="605"/>
        <source>Draw Circle</source>
        <translation>Коло</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="608"/>
        <source>Draw a hollow circle</source>
        <translation>Малювати еліптичну раму</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="620"/>
        <source>Draw Number</source>
        <translation>Цифри</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="623"/>
        <source>Draw incrementing numbers</source>
        <translation>Малювати цифри у зростаючому порядку</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="631"/>
        <source>&amp;Annotations Toolbar</source>
        <translation>&amp;Панель анотацій</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="642"/>
        <location filename="../mainwindow.ui" line="645"/>
        <source>Show Outline</source>
        <translation>Показувати контур</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="648"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="656"/>
        <source>Copy Pa&amp;th</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="659"/>
        <source>Copy path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="668"/>
        <source>Resize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>&amp;Help</source>
        <translation>&amp;Довідка</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>Go</source>
        <translation>Перейти</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>&amp;View</source>
        <translation>П&amp;ерегляд</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="128"/>
        <source>&amp;Edit</source>
        <translation>&amp;Редагування</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="153"/>
        <source>Toolbar</source>
        <translation>Панель інструментів</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Налаштування</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Тема значків:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="43"/>
        <source>Normal background color:</source>
        <translation>Нормальний колір тла:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="50"/>
        <source>Fullscreen background color:</source>
        <translation>Колір тла повного екрану:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="71"/>
        <source>Maximum number of recent files:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="81"/>
        <source>Slide show interval (seconds):</source>
        <translation>Інтервал слайд-шоу (секунди):</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="95"/>
        <source>Show image outline by default</source>
        <translation>Типово показувати контур</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="102"/>
        <source>Show annotations toolbar by default</source>
        <translation>Типово показувати панель анотацій</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="110"/>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="129"/>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="134"/>
        <source>Shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="142"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Загальне</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="830"/>
        <source>Error</source>
        <translation type="unfinished">Помилка</translation>
    </message>
</context>
<context>
    <name>ResizeImageDialog</name>
    <message>
        <location filename="../resizeimagedialog.ui" line="14"/>
        <source>Resize Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="26"/>
        <source>Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="33"/>
        <source>Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="40"/>
        <source>Current size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="80"/>
        <source>New size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="93"/>
        <location filename="../resizeimagedialog.ui" line="116"/>
        <source> px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="129"/>
        <location filename="../resizeimagedialog.ui" line="158"/>
        <source> %</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="174"/>
        <source>Keep aspect ratio</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Знімок екрану</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Зробити знімок</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Регіон</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Екран цілком</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Лише поточне вікно</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>Захопити частину екрану</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Включаючи вказівник миші</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="74"/>
        <source> sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Затримка:</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Включаючи заголовок вікна та кадр</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>Вивантажити</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.ui" line="39"/>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
</context>
</TS>
